@@ -22,17 +22,26 @@ from maestral.utils.autostart import AutoStart
 from . import __version__, __author__, __url__
 from .selective_sync_dialog import SelectiveSyncDialog
 from .resources import (
-    native_item_icon, UNLINK_DIALOG_PATH,
-    SETTINGS_WINDOW_PATH, APP_ICON_PATH, FACEHOLDER_PATH
+    native_item_icon,
+    UNLINK_DIALOG_PATH,
+    SETTINGS_WINDOW_PATH,
+    APP_ICON_PATH,
+    FACEHOLDER_PATH,
 )
 from .utils import (
-    IS_MACOS, LINE_COLOR_DARK, LINE_COLOR_LIGHT,
-    get_scaled_font, is_dark_window, center_window,
-    icon_to_pixmap, get_masked_image, MaestralBackgroundTask
+    IS_MACOS,
+    LINE_COLOR_DARK,
+    LINE_COLOR_LIGHT,
+    get_scaled_font,
+    is_dark_window,
+    center_window,
+    icon_to_pixmap,
+    get_masked_image,
+    MaestralBackgroundTask,
 )
 from .widgets import UserDialog
 
-NEW_QT = LooseVersion(QtCore.QT_VERSION_STR) >= LooseVersion('5.11')
+NEW_QT = LooseVersion(QtCore.QT_VERSION_STR) >= LooseVersion("5.11")
 
 
 class UnlinkDialog(QtWidgets.QDialog):
@@ -49,7 +58,7 @@ class UnlinkDialog(QtWidgets.QDialog):
         self.restart_func = restart_func
         self.mdbx = mdbx
 
-        self.buttonBox.buttons()[0].setText('Unlink')
+        self.buttonBox.buttons()[0].setText("Unlink")
         self.titleLabel.setFont(get_scaled_font(bold=True))
         self.infoLabel.setFont(get_scaled_font(scaling=0.9))
 
@@ -61,7 +70,9 @@ class UnlinkDialog(QtWidgets.QDialog):
 
         self.buttonBox.setEnabled(False)
         self.progressIndicator.startAnimation()
-        self.unlink_thread = MaestralBackgroundTask(self, self.mdbx.config_name, 'unlink')
+        self.unlink_thread = MaestralBackgroundTask(
+            self, self.mdbx.config_name, "unlink"
+        )
         self.unlink_thread.sig_done.connect(self.restart_func)
 
 
@@ -69,7 +80,12 @@ class UnlinkDialog(QtWidgets.QDialog):
 class SettingsWindow(QtWidgets.QWidget):
     """A widget showing all of Maestral's settings."""
 
-    _update_interval_mapping = {0: 60*60*24, 1: 60*60*24*7, 2: 60*60*24*30, 3: 0}
+    _update_interval_mapping = {
+        0: 60 * 60 * 24,
+        1: 60 * 60 * 24 * 7,
+        2: 60 * 60 * 24 * 30,
+        3: 0,
+    }
 
     def __init__(self, parent, mdbx):
         super().__init__()
@@ -106,17 +122,21 @@ class SettingsWindow(QtWidgets.QWidget):
 
         # connect callbacks
         self.pushButtonUnlink.clicked.connect(self.unlink_dialog.exec_)
-        self.pushButtonExcludedFolders.clicked.connect(self.selective_sync_dialog.populate_folders_list)
+        self.pushButtonExcludedFolders.clicked.connect(
+            self.selective_sync_dialog.populate_folders_list
+        )
         self.pushButtonExcludedFolders.clicked.connect(self.selective_sync_dialog.open)
         self.checkBoxStartup.stateChanged.connect(self.on_start_on_login_clicked)
         self.checkBoxNotifications.stateChanged.connect(self.on_notifications_clicked)
         self.checkBoxAnalytics.stateChanged.connect(self.on_analytics_clicked)
         self.comboBoxUpdateInterval.currentIndexChanged.connect(
-            self.on_combobox_update_interval)
+            self.on_combobox_update_interval
+        )
         self.comboBoxDropboxPath.currentIndexChanged.connect(self.on_combobox_path)
-        msg = ('Choose a location for your Dropbox. A folder named "{0}" will be ' +
-               'created inside the folder you select.').format(
-                   self.mdbx.get_conf('main', 'default_dir_name'))
+        msg = (
+            'Choose a location for your Dropbox. A folder named "{0}" will be '
+            + "created inside the folder you select."
+        ).format(self.mdbx.get_conf("main", "default_dir_name"))
         self.dropbox_folder_dialog = QtWidgets.QFileDialog(self, caption=msg)
         self.dropbox_folder_dialog.setModal(True)
         self.dropbox_folder_dialog.setAcceptMode(QtWidgets.QFileDialog.AcceptOpen)
@@ -124,7 +144,8 @@ class SettingsWindow(QtWidgets.QWidget):
         self.dropbox_folder_dialog.setOption(QtWidgets.QFileDialog.ShowDirsOnly)
         self.dropbox_folder_dialog.fileSelected.connect(self.on_new_dbx_folder)
         self.dropbox_folder_dialog.rejected.connect(
-                lambda: self.comboBoxDropboxPath.setCurrentIndex(0))
+            lambda: self.comboBoxDropboxPath.setCurrentIndex(0)
+        )
 
         center_window(self)
 
@@ -143,29 +164,33 @@ class SettingsWindow(QtWidgets.QWidget):
         self.comboBoxDropboxPath.clear()
         self.comboBoxDropboxPath.addItem(folder_icon, relative_path)
         self.comboBoxDropboxPath.insertSeparator(1)
-        self.comboBoxDropboxPath.addItem(QtGui.QIcon(), 'Other...')
+        self.comboBoxDropboxPath.addItem(QtGui.QIcon(), "Other...")
 
         # populate app section
         self.checkBoxStartup.setChecked(self.autostart.enabled)
         self.checkBoxNotifications.setChecked(self.mdbx.notification_level <= 15)
         self.checkBoxAnalytics.setChecked(self.mdbx.analytics)
-        update_interval = self.mdbx.get_conf('app', 'update_notification_interval')
+        update_interval = self.mdbx.get_conf("app", "update_notification_interval")
         closest_key = min(
             self._update_interval_mapping,
-            key=lambda x: abs(self._update_interval_mapping[x] - update_interval)
+            key=lambda x: abs(self._update_interval_mapping[x] - update_interval),
         )
         self.comboBoxUpdateInterval.setCurrentIndex(closest_key)
 
         # populate about section
         year = time.localtime().tm_year
-        self.labelVersion.setText(self.labelVersion.text().format(__version__, __daemon_version__))
+        self.labelVersion.setText(
+            self.labelVersion.text().format(__version__, __daemon_version__)
+        )
         self.labelUrl.setText(self.labelUrl.text().format(__url__))
         self.labelCopyright.setText(self.labelCopyright.text().format(year, __author__))
 
     def set_profile_pic_from_cache(self):
 
         try:
-            pixmap = get_masked_image(self.mdbx.account_profile_pic_path, size=self._profile_pic_height)
+            pixmap = get_masked_image(
+                self.mdbx.account_profile_pic_path, size=self._profile_pic_height
+            )
         except OSError:
             pixmap = get_masked_image(FACEHOLDER_PATH, size=self._profile_pic_height)
 
@@ -173,30 +198,34 @@ class SettingsWindow(QtWidgets.QWidget):
 
     def set_account_info_from_cache(self):
 
-        acc_display_name = self.mdbx.get_state('account', 'display_name')
-        acc_mail = self.mdbx.get_state('account', 'email')
-        acc_type = self.mdbx.get_state('account', 'type')
-        acc_space_usage = self.mdbx.get_state('account', 'usage')
-        acc_space_usage_type = self.mdbx.get_state('account', 'usage_type')
+        acc_display_name = self.mdbx.get_state("account", "display_name")
+        acc_mail = self.mdbx.get_state("account", "email")
+        acc_type = self.mdbx.get_state("account", "type")
+        acc_space_usage = self.mdbx.get_state("account", "usage")
+        acc_space_usage_type = self.mdbx.get_state("account", "usage_type")
 
-        if acc_space_usage_type == 'team':
-            acc_space_usage += ' (Team)'
+        if acc_space_usage_type == "team":
+            acc_space_usage += " (Team)"
 
         # if the display name is longer than 230 pixels, reduce font-size
         default_font = get_scaled_font(1.5)
         if NEW_QT:
-            account_display_name_length = QtGui.QFontMetrics(default_font).horizontalAdvance(acc_display_name)
+            account_display_name_length = QtGui.QFontMetrics(
+                default_font
+            ).horizontalAdvance(acc_display_name)
         else:
-            account_display_name_length = QtGui.QFontMetrics(default_font).width(acc_display_name)
+            account_display_name_length = QtGui.QFontMetrics(default_font).width(
+                acc_display_name
+            )
         if account_display_name_length > 240:
-            font = get_scaled_font(scaling=1.5*240/account_display_name_length)
+            font = get_scaled_font(scaling=1.5 * 240 / account_display_name_length)
             self.labelAccountName.setFont(font)
         self.labelAccountName.setText(acc_display_name)
 
-        if acc_type != '':
-            acc_type_text = ', Dropbox {0}'.format(acc_type.capitalize())
+        if acc_type != "":
+            acc_type_text = ", Dropbox {0}".format(acc_type.capitalize())
         else:
-            acc_type_text = ''
+            acc_type_text = ""
         self.labelAccountInfo.setText(acc_mail + acc_type_text)
         self.labelSpaceUsage.setText(acc_space_usage)
 
@@ -207,24 +236,28 @@ class SettingsWindow(QtWidgets.QWidget):
 
     @QtCore.pyqtSlot(int)
     def on_combobox_update_interval(self, idx):
-        self.mdbx.set_conf('app', 'update_notification_interval',
-                           self._update_interval_mapping[idx])
+        self.mdbx.set_conf(
+            "app", "update_notification_interval", self._update_interval_mapping[idx]
+        )
 
     @QtCore.pyqtSlot(str)
     def on_new_dbx_folder(self, new_location):
 
         self.comboBoxDropboxPath.setCurrentIndex(0)
-        if not new_location == '':
+        if not new_location == "":
 
-            new_path = osp.join(new_location,
-                                self.mdbx.get_conf('main', 'default_dir_name'))
+            new_path = osp.join(
+                new_location, self.mdbx.get_conf("main", "default_dir_name")
+            )
 
             try:
                 self.mdbx.move_dropbox_directory(new_path)
             except OSError:
-                msg = ('Please check if you have permissions to write to the '
-                       'selected location.')
-                msg_box = UserDialog('Could not create directory', msg, parent=self)
+                msg = (
+                    "Please check if you have permissions to write to the "
+                    "selected location."
+                )
+                msg_box = UserDialog("Could not create directory", msg, parent=self)
                 msg_box.open()  # no need to block with exec
                 self.mdbx.resume_sync()
             else:
@@ -262,7 +295,7 @@ class SettingsWindow(QtWidgets.QWidget):
 
     def update_dark_mode(self):
         rgb = LINE_COLOR_DARK if is_dark_window() else LINE_COLOR_LIGHT
-        line_style = 'color: rgb({0}, {1}, {2})'.format(*rgb)
+        line_style = "color: rgb({0}, {1}, {2})".format(*rgb)
 
         self.line0.setStyleSheet(line_style)
         self.line1.setStyleSheet(line_style)
